GraphQLClientSettings class

Store settings of GraphQLClient.

Annotations
  • @sealed

Constructors

GraphQLClientSettings({required LinkFactory linkFactory, required CacheFactory cacheFactory, bool alwaysRebroadcast = false, DefaultPolicies? defaultPolicies})
Store settings of GraphQLClient.

Properties

alwaysRebroadcast bool
An alias of QueryManager.alwaysRebroadcast.
final
cacheFactory CacheFactory
Factory to create GraphQLClient.cache.
final
defaultPolicies DefaultPolicies?
An alias of GraphQLClient.defaultPolicies.
final
hashCode int
The hash code for this object.
no setterinherited
linkFactory LinkFactory
Factory to create GraphQLClient.link.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited